#[non_exhaustive]pub enum Event<'a> {
Begin {
serial: u32,
time: u32,
surface: WlSurface,
fingers: u32,
},
End {
serial: u32,
time: u32,
cancelled: i32,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Begin
multi-finger hold begin
This event is sent when a hold gesture is detected on the device.
Only available since version 3 of the interface
Fields
End
multi-finger hold end
This event is sent when a hold gesture ceases to be valid. This may happen when the holding fingers are lifted or the gesture is cancelled, for example if the fingers move past an implementation-defined threshold, the finger count changes or the hold gesture changes into a different type of gesture.
When a gesture is cancelled, the client may need to undo state changes caused by this gesture. What causes a gesture to be cancelled is implementation-dependent.
Only available since version 3 of the interface
Implementations