pub struct ZwpPointerGestureHoldV1 { /* private fields */ }Expand description
a hold gesture object
A hold gesture object notifies a client about a single- or multi-finger hold gesture detected on an indirect input device such as a touchpad. The gesture is usually initiated by one or more fingers being held down without significant movement. The precise conditions of when such a gesture is detected are implementation-dependent.
In particular, this gesture may be used to cancel kinetic scrolling.
A hold gesture consists of two stages: begin and end. Unlike pinch and swipe there is no update stage. There cannot be multiple simultaneous hold, pinch or swipe gestures on a same pointer/seat, how compositors prevent these situations is implementation-dependent.
A gesture may be cancelled by the compositor or the hardware. Clients should not consider performing permanent or irreversible actions until the end of a gesture has been received.
See also the Request enum for this interface.
Implementations
Sourceimpl ZwpPointerGestureHoldV1
impl ZwpPointerGestureHoldV1
Sourcepub fn begin(&self, serial: u32, time: u32, surface: &WlSurface, fingers: u32)
pub fn begin(&self, serial: u32, time: u32, surface: &WlSurface, fingers: u32)
multi-finger hold begin
This event is sent when a hold gesture is detected on the device.
Sourcepub fn end(&self, serial: u32, time: u32, cancelled: i32)
pub fn end(&self, serial: u32, time: u32, cancelled: i32)
multi-finger hold end
This event is sent when a hold gesture ceases to be valid. This may happen when the holding fingers are lifted or the gesture is cancelled, for example if the fingers move past an implementation-defined threshold, the finger count changes or the hold gesture changes into a different type of gesture.
When a gesture is cancelled, the client may need to undo state changes caused by this gesture. What causes a gesture to be cancelled is implementation-dependent.